==> haskell-contravariant-1.4-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.4
id: contravariant-1.4-40742dd1a022cbf40c8c77a36d4f0610
key: contr_0bhKhIAahbT1iQuySQ0tsy
license: BSD3
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors
category: Control, Data
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Functor.Contravariant Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-1.4
hs-libraries: HScontravariant-1.4-0bhKhIAahbT1iQuySQ0tsy
depends:
    StateVar-1.1.0.3-dfbaaa5b80efc1d36dff08b16817e21d
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.4-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-contravariant/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant
version: 1.4
id: contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
key: contr_7dAWB2x4yN9BZDQgwGJsfm
license: BSD3
copyright: Copyright (C) 2007-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/contravariant/
synopsis: Contravariant functors
description:
    Contravariant functors
category: Control, Data
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Functor.Contravariant Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-1.4
hs-libraries: HScontravariant-1.4-7dAWB2x4yN9BZDQgwGJsfm
depends:
    StateVar-1.1.0.3-dfbaaa5b80efc1d36dff08b16817e21d
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
haddock-interfaces: /usr/share/doc/haskell-contravariant/html/contravariant.haddock
haddock-html: /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
